##  Choose a Language
Select your preferred language from the language menu at the top of the page. Real-time machine translation is available in 39 languages.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9940a2566c5a4dd0882311653ca7a4fd_LowRes.png)
Selecting a Language
